##########################################################################
#                                                                        #
#        KINGS QUEST II [Quick Solution Series] By Phil J.Jatzek.        #
#                                                                        #
##########################################################################

##########################################################################
#                                                                        #
#                  KINGS QUEST II GAME BOARD MAP:                        #
#            +------------------------------------------+                #
#            |    CROSS-OVER  CROSS-OVER  CROSS-OVER    |                #
#            |   +----+----+----+----+----+----+----+ M |                #
#            | O | 1  | 2  | 3  | 4  | 5  | 6  | 7  | O |                #
#            | C |    |    |    |    |    |    |    | U |                #
#            | E +----+----+----+----+----+----+----+ N |                #
#            | A | 8  | 9  | 10 | 11 | 12 | 13 | 14 | T |                #
#	     | N |    |    |    |    |    |    |    | I |                #
#	     |   +----+----+----+----+----+----+----+ A |                #
#	     | O | 15 | 16 | 17 | 18 | 19 | 20 | 21 | N |                #
#	     | C |    |    |    |    |    |    |    | S |                #
#	     | E +----+----+----+----+----+----+----+   |                #
#	     | A | 22 | 23 | 24 | 25 | 26 | 27 | 28 | M |                #
#	     | N |    |    |    |    |    |    |    | O |                #
#	     |   +----+----+----+----+----+----+----+ U |                #
#	     | O | 29 | 30 | 31 | 32 | 33 | 34 | 35 | N |                #
#	     | C |    |    |    |    |    |    |    | T |                #
#	     | E +----+----+----+----+----+----+----+ I |                #
#	     | A | 36 | 37 | 38 | 39 | 40 | 41 | 42 | A |                #
#	     | N |    |    |    |    |    |    |    | N |                #
#	     |   +----+----+----+----+----+----+----+ S |                #
#	     |    CROSS-OVER  CROSS-OVER  CROSS-OVER    |                #
#            +------------------------------------------+                #
#                                                                        #
##########################################################################

##########################################################################
#                                                                        #
# NOTE: For the above map; Each game screen of the Kings Quest 2         #
#       domain is equal to one square on the above map. will             #
#       automatically start out on square one. It is a good idea         #
#       to actually draw out location landmarks on the above map         #
#       to help serve as reference through out the game.(ie: Store,      #
#       dead lake, house, bridge, canyon, etc.) This quick solution      #
#       does not tell you how to get the maximum score but just how to   #
#       finish the game. So you will have to weasel around if you want   #
#       to scrap up extra points.(ie: kill the vampire, wolf, witch,     #
#       enchanter, (supposibly), give the basket of goodies to little    #
#       red riding hood for flowers, etc.) Wandering monster will appear #
#       once and a while on different areas of the game map. You have    #
#       three choices 1: Stay only if under protection spell.(or die)    #
#                     2: Find a way to kill the monster.                 #
#                    3: Run for your life off the screen.                #
#       Your main objective in this game is to obtain THREE keys inorder #
#       to unlock a magic door. Once the door has been opened then you   #
#       journey to the other side of it and try to find the damsel in    #
#       distress (locked within a tower on a desolate island). You       #
#       eventually marry and win the game.                               #
#                                                                        #
##########################################################################

##########################################################################
#                                                                        #
# KEY ONE: (* = wandering monster possiblity)                            #
# ======== (Does not matter what order you obtain the follow object,     #
#          only that you obtain them all before continuing)              #
#                                                                        #
##########################################################################
#                                                                        #
# +--------------------------------------------------------------------+ #
# |Goto:   3 - open box, get basket.                                   | #
# |        6 - open door, pray, sir graham, leave.                     | #
# |       13 - look opening, get brooch.                               | #
# |       16 - get stake.                                              | #
# |       22 - get shell, get bracelet.                                | #
# |       29 - get trident.                                            | #
# |       31   look stump, get necklace.                               | #
# |       33 - look hole, get mallet.                                  | #
# |     * 37 - get bird.                                               | #
# |     * 39 - open door, down, right, open chest, look in chest, get  | #
# |            earrings, leave.                                        | #
# +--------------------------------------------------------------------+ #
#                                                                        #
# Goto: 35- look door, read door.                                        #
#       15 - swim, look mermaid, give necklace to mermaid, ride horse,   #
#            give trident to neptune, get key, leave.                    #
#       35 - unlock door, read door.                                     #
#                                                                        #
##########################################################################

##########################################################################
#                                                                        #
# KEY TWO: (* = wandering monsterpossiblity)                             #
# ======== (The carpet will only fly if you are in front of the store)   #
#                                                                        #
##########################################################################
#                                                                        #
# Goto: * 20 - open door, give brooch to lady, give earrings to lady,    #
#              get cloth, rublamp, ride carpet, right, rub lamp, kill    #
#              snake, right, enter cave, get key, exit cave, look hole,  #
#              ride carpet.                                              #
#         35 - unlock door, read door.                                   #
#                                                                        #
##########################################################################

##########################################################################
#                                                                        #
# KEY THREE: (* = wandering monster possiblity)                          #
# ========== (The path to the castle is lines with posionious thorns)    #
#                                                                        #
##########################################################################
#                                                                        #
# Goto: * 25 - give bracelet to feind, get in boat, get out of boat,     #
#              wear cross, open door, left, up, open drawer, get candle, #
#              down to torch, light candle, down, right, right, get ham, #
#              right, down, left, look in coffin, get pillow, get key,   #
#              leave castle, get in boat.                                #
#         35 - unlock door.                                              #
#                                                                        #
##########################################################################

##########################################################################
#                                                                        #
#                     THE OTHER SIDE GAME BOARD MAP:                     #
#	       +------------------------------------------+              #
#	       |     CLIFF               OCEAN  OCEAN     |              #
#	       |    +----+             +----+----+----+   |              #
#	       |  M | B  |             | 7  | 8  | 9  |   |              #
#	       |  O |    | O         O |    |    |    | O |              #
#	       |  U +----+ C         C +----+----+----+ C |              #
#	       |  N | A  | E         E | 6  | 5  | 4  | E |              #
#	       |  T |    | A         A |    |    |    | A |              #
#	       |  I +----+ N         N +----+----+----+ N |              #
#	       |  A | C  |             | 1  | 2  | 3  |   |              #
#	       |  N |    | <---------> |    |    |    |   |              #
#	       |    +----+             +----+----+----+   |              #
#	       |     CLIFF               OCEAN  OCEAN     |              #
#	       +------------------------------------------+              #
#                                                                        #
##########################################################################

#########################################################################
#                                                                       #
# THE OTHER SIDE: (Can't go back except by winning the game)            #
# ===============                                                       #
#                                                                       #
#########################################################################
#                                                                       #
# Goto:   B - get net.                                                  #
#         C - fish, get fish, throw fish, ride fish.                    #
#         8 - get amulet.                                               #
#         5 - open door, up, up, feed lion, open door, kiss girl, look  #
#             amulet, HOME.                                             #
#                                                                       #
#########################################################################

#########################################################################
#                          <<< GAME OVER >>>                            #
#########################################################################
#                                                                       #
#               KINGS QUEST II [Quick Solution Series]                  #
#          	      Written By Phil J.Jatzek                          #
#                                                                       #
#		 Look for these other Quick Solutions:                  #
#                                                                       #
#  KINGS QUEST Series  LEISURE SUIT LARRY Series  ULTIMA Series         #
#  SPACE QUEST Series  POLICE QUEST Series        BARDS TALES Series.   #
#                                                                       #
#                        And Many Many More!                            #
#                                                                       #
#########################################################################
